argument_index_of_place

Function argument_index_of_place 

fn argument_index_of_place(
    tcx: TyCtxt<'_>,
    checkpoint: &Checkpoint<'_>,
    place: &PlaceKey,
) -> Option<(PlaceKey, usize)>
Map a root place to its callee argument index, if it is an Arg or a Local that traces to a callee parameter.