pub fn place_projection_uses(place: &Place<'_>) -> RelevantPlacesExpand description
Collect only the index roots used by a place projection.
pub fn place_projection_uses(place: &Place<'_>) -> RelevantPlacesCollect only the index roots used by a place projection.