PlaceKey

Struct PlaceKey 

pub struct PlaceKey {
    pub base: PlaceBaseKey,
    pub fields: Vec<usize>,
}
Projection-insensitive enough place key for relevance tracking.

Fields

base: PlaceBaseKey

Base local/argument of the place.

fields: Vec<usize>

Field projections kept from the contract place.

Implementations

Source

impl PlaceKey

pub fn from_contract_place(place: &ContractPlace<'_>) -> Self

Build a relevance place key from a parsed contract place.

pub fn from_mir_place(place: &Place<'_>) -> Self

Build a relevance place key from a MIR place.

pub fn local(&self) -> Option<Local>

Return the MIR local represented by this key when it is already known.

pub fn overlaps(&self, other: &PlaceKey) -> bool

Return true when this place shares a base-and-projection prefix with other. Two places overlap when one of them is a shorter projection of the other (e.g. [] overlaps [0], but [0] does not overlap [1]).